@@ -50,16 +50,23 @@
 package com.openexchange.realtime.atmosphere.osgi;
 
 import org.osgi.framework.BundleContext;
+import com.openexchange.ajax.requesthandler.osgiservice.AJAXModuleActivator;
 import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.conversion.simple.SimpleConverter;
 import com.openexchange.conversion.simple.SimplePayloadConverter;
 import com.openexchange.http.grizzly.service.atmosphere.AtmosphereService;
-import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.realtime.Channel;
 import com.openexchange.realtime.atmosphere.AtmosphereConfig;
+import com.openexchange.realtime.atmosphere.http.RealtimeActions;
 import com.openexchange.realtime.atmosphere.impl.RTAtmosphereChannel;
 import com.openexchange.realtime.atmosphere.impl.RTAtmosphereHandler;
+import com.openexchange.realtime.atmosphere.payload.converter.JSONToRealtimeExceptionConverter;
+import com.openexchange.realtime.atmosphere.payload.converter.JSONToStackTraceElementConverter;
+import com.openexchange.realtime.atmosphere.payload.converter.JSONToThrowableConverter;
+import com.openexchange.realtime.atmosphere.payload.converter.RealtimeExceptionToJSONConverter;
+import com.openexchange.realtime.atmosphere.payload.converter.StackTraceElementToJSONConverter;
+import com.openexchange.realtime.atmosphere.payload.converter.ThrowableToJSONConverter;
 import com.openexchange.realtime.atmosphere.payload.converter.primitive.ByteToJSONConverter;
 import com.openexchange.realtime.atmosphere.payload.converter.primitive.JSONToByteConverter;
 import com.openexchange.realtime.atmosphere.payload.converter.primitive.JSONToStringConverter;
@@ -68,15 +75,17 @@ import com.openexchange.realtime.atmosphere.presence.converter.JSONToPresenceSta
 import com.openexchange.realtime.atmosphere.presence.converter.PresenceStateToJSONConverter;
 import com.openexchange.realtime.directory.ResourceDirectory;
 import com.openexchange.realtime.dispatch.MessageDispatcher;
+import com.openexchange.realtime.exception.RealtimeException;
 import com.openexchange.realtime.handle.StanzaQueueService;
 import com.openexchange.realtime.packet.Presence;
 import com.openexchange.realtime.packet.PresenceState;
+import com.openexchange.realtime.packet.Stanza;
 import com.openexchange.realtime.payload.converter.PayloadTreeConverter;
 import com.openexchange.sessiond.SessiondService;
 import com.openexchange.threadpool.ThreadPoolService;
 import com.openexchange.timer.TimerService;
 
-public class AtmosphereRTActivator extends HousekeepingActivator {
+public class AtmosphereRTActivator extends AJAXModuleActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
@@ -93,7 +102,6 @@ public class AtmosphereRTActivator extends HousekeepingActivator {
 
         AtmosphereService atmosphereService = getService(AtmosphereService.class);
         RTAtmosphereHandler handler = new RTAtmosphereHandler();
-        handler.init();
         atmosphereService.addAtmosphereHandler("rt", handler);
         registerService(Channel.class, new RTAtmosphereChannel(handler));
 
@@ -110,12 +118,21 @@ public class AtmosphereRTActivator extends HousekeepingActivator {
         registerService(SimplePayloadConverter.class, new JSONToStringConverter());
         registerService(SimplePayloadConverter.class, new JSONToPresenceStateConverter());
         registerService(SimplePayloadConverter.class, new PresenceStateToJSONConverter());
+        registerService(SimplePayloadConverter.class, new JSONToStackTraceElementConverter());
+        registerService(SimplePayloadConverter.class, new StackTraceElementToJSONConverter());
+        registerService(SimplePayloadConverter.class, new JSONToThrowableConverter());
+        registerService(SimplePayloadConverter.class, new ThrowableToJSONConverter());
+        registerService(SimplePayloadConverter.class, new JSONToRealtimeExceptionConverter());
+        registerService(SimplePayloadConverter.class, new RealtimeExceptionToJSONConverter());
 
         // Add Transformers using Converters
         PayloadTreeConverter converter = getService(PayloadTreeConverter.class);
         converter.declarePreferredFormat(Presence.STATUS_PATH, PresenceState.class.getSimpleName());
         converter.declarePreferredFormat(Presence.MESSAGE_PATH, String.class.getSimpleName());
         converter.declarePreferredFormat(Presence.PRIORITY_PATH, Byte.class.getSimpleName());
+        converter.declarePreferredFormat(Stanza.ERROR_PATH, RealtimeException.class.getSimpleName());
+        
+        registerModule(new RealtimeActions(this, handler.getStateManager(), handler.getProtocolHandler()), "rt");
 
         getService(CapabilityService.class).declareCapability("rt");
 
